@@ -3,12 +3,15 @@ from .request import ScrapflyScrapyRequest
 from .response import ScrapflyScrapyResponse
 from .middleware import ScrapflyMiddleware
 from .spider import ScrapflySpider, ScrapflyCrawlSpider
+from .pipelines import FilesPipeline, ImagesPipeline
 
 __all__:Tuple[str, ...] = (
     'ScrapflyScrapyRequest',
     'ScrapflyScrapyResponse',
     'ScrapflyMiddleware',
     'ScrapflySpider',
-    'ScrapflyCrawlSpider'
+    'ScrapflyCrawlSpider',
+    'FilesPipeline',
+    'ImagesPipeline'
 )
 
